@@ -1,16 +1,16 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
 from trytond.model import Model, fields
-from trytond.pyson import Not, Bool, Eval
-import luhn
+from trytond.pyson import Eval
+from . import luhn
 
 
 class Party(Model):
     _name = 'party.party'
 
-    siren = fields.Char('SIREN', select=1, states={
-        'readonly': Not(Bool(Eval('active'))),
-        }, size=9)
+    siren = fields.Char('SIREN', select=True, states={
+            'readonly': ~Eval('active', True),
+            }, size=9, depends=['active'])
 
     def __init__(self):
         super(Party, self).__init__()
